@@ -8,6 +8,13 @@ def captureImg(filepath):
     del camera
 
 
+def getImage():
+    camera = cv2.VideoCapture(0)
+    return_value, image = camera.read()
+    del camera
+    return image
+
+
 def blur(image, intensity: tuple):
     blurred = cv2.GaussianBlur(image, intensity, cv2.BORDER_DEFAULT)
     return blurred
